@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef LSKAT_GAMEVIEW_H
@@ -68,7 +55,7 @@ protected:
      */
     void mouseReleaseEvent(QMouseEvent *event) override;
 
-public slots:
+public Q_SLOTS:
     /**
      * The update and advance for the canvas.
      * This is called by a timer at regular intervals.
@@ -80,7 +67,7 @@ public slots:
      */
     void rescaleTheme();
 
-signals:
+Q_SIGNALS:
     /**
      * Emit the signal on mouse clicks.
      * @param point The mouse coordinate.
